
From: Roland Dreier <roland@topspin.com>

Add a mthca_write_db_rec() to wrap writing doorbell records.  On
64-bit archs, this is just a 64-bit write, while on 32-bit archs it
splits the write into two 32-bit writes with a memory barrier to make
sure the two halves of the record are written in the correct order.

Signed-off-by: Roland Dreier <roland@topspin.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/drivers/infiniband/hw/mthca/mthca_doorbell.h |   12 ++++++++++++
 1 files changed, 12 insertions(+)

diff -puN drivers/infiniband/hw/mthca/mthca_doorbell.h~ib-mthca-mem-free-doorbell-record-writing drivers/infiniband/hw/mthca/mthca_doorbell.h
--- 25/drivers/infiniband/hw/mthca/mthca_doorbell.h~ib-mthca-mem-free-doorbell-record-writing	2005-03-03 17:40:09.000000000 -0800
+++ 25-akpm/drivers/infiniband/hw/mthca/mthca_doorbell.h	2005-03-03 17:40:09.000000000 -0800
@@ -57,6 +57,11 @@ static inline void mthca_write64(u32 val
 	__raw_writeq(*(u64 *) val, dest);
 }
 
+static inline void mthca_write_db_rec(u32 val[2], u32 *db)
+{
+	*(u64 *) db = *(u64 *) val;
+}
+
 #else
 
 /*
@@ -80,4 +85,11 @@ static inline void mthca_write64(u32 val
 	spin_unlock_irqrestore(doorbell_lock, flags);
 }
 
+static inline void mthca_write_db_rec(u32 val[2], u32 *db)
+{
+	db[0] = val[0];
+	wmb();
+	db[1] = val[1];
+}
+
 #endif
_
